calculate_separation: Calculate Concept Separation

View source: R/metrics.R

calculate_separationR Documentation

Calculate Concept Separation

Description

Computes the separation of each concept. Separation is defined as the number of objects in a concept's extent that are NOT covered by any of its immediate subconcepts (children).

Usage

calculate_separation(lattice)

Arguments

lattice

A ConceptLattice object.

Value

A numeric vector of separation values.


fcaR documentation built on July 27, 2026, 5:06 p.m.