calculate_stability: Calculate Concept Stability

View source: R/stability.R View source: R/metrics.R

calculate_stabilityR Documentation

Calculate Concept Stability

Description

Calculates the intensional stability of each concept.

Calculates the intensional stability of each concept in the lattice directly from the sparse matrix representation. Stability measures the probability that a concept is preserved when a random subset of objects is removed.

Usage

calculate_stability(extents)

calculate_stability(extents)

Arguments

extents

A SparseSet object or a sparse matrix (CsparseMatrix) representing concept extents (columns are concepts).

Value

A numeric vector.

A numeric vector with stability values in [0, 1].


fcaR documentation built on July 27, 2026, 5:06 p.m.