conceptRegistry: Concept Miners Registry

conceptRegistryR Documentation

Concept Miners Registry

Description

Concept Miners Registry

Usage

conceptRegistry

Format

An object of class concept_miner_registry (inherits from registry) of length 3.

Details

This is a registry that stores the concept miners that can be applied using the find_concepts() method in an FormalConcept.

One can obtain the list of available equivalence operators by: conceptRegistry$get_entry_names()


fcaR documentation built on July 27, 2026, 5:06 p.m.