Skip to contents

A dataset representing the 24 classical characters from the Guess Who board game with their 19 binary attributes.

Usage

guesswho

Format

A matrix with 24 rows and 19 columns. Column names correspond to the physical attributes:

Gender

Male, Female.

Hair Color

BlackHair, WhiteHair, BlondeHair, BrownHair, RedHair.

Baldness

Bald.

Eye Color

BlueEyes, BrownEyes.

Facial Hair

Moustache, Beard.

Accessories

Hat, Glasses, Earrings.

Other features

RosyCheeks, BigNose, BigMouth, Sad.

Each entry contains a 1 if the character possesses the trait and a 0 otherwise.

Extracted from the physical version of the Guess Who board game characters.