select_repository_context: GUI to select and download a context from the repository

View source: R/repository.R

select_repository_contextR Documentation

GUI to select and download a context from the repository

Description

GUI to select and download a context from the repository

Usage

select_repository_context(meta)

Arguments

meta

A list of metadata objects (obtained via get_fcarepository_contexts).


fcaR documentation built on July 27, 2026, 5:06 p.m.