View source: R/random_contexts.R
| RandomDistributiveContext | R Documentation |
Generates a random formal context that is guaranteed to produce a Distributive Concept Lattice.
It relies on Birkhoff's Representation Theorem: The lattice of order ideals
of a Poset is always distributive. The context is constructed such that
objects and attributes are the elements of the poset, and the incidence
relation is g I m \iff \neg(g \ge m).
RandomDistributiveContext(n_elements, density = 0.1)
n_elements |
Number of elements in the underlying Poset. |
density |
Probability of an order relation |
A FormalContext.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.