| calculate_separation | R Documentation |
Computes the separation of each concept. Separation is defined as the number of objects in a concept's extent that are NOT covered by any of its immediate subconcepts (children).
calculate_separation(lattice)
lattice |
A |
A numeric vector of separation values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.