View source: R/stability.R View source: R/metrics.R
| calculate_stability | R Documentation |
Calculates the intensional stability of each concept.
Calculates the intensional stability of each concept in the lattice directly from the sparse matrix representation. Stability measures the probability that a concept is preserved when a random subset of objects is removed.
calculate_stability(extents)
calculate_stability(extents)
extents |
A |
A numeric vector.
A numeric vector with stability values in [0, 1].
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.