| conceptRegistry | R Documentation |
Concept Miners Registry
conceptRegistry
An object of class concept_miner_registry (inherits from registry) of length 3.
This is a registry that stores the concept miners that can be
applied using the find_concepts() method in an
FormalConcept.
One can obtain the list of available equivalence operators by:
conceptRegistry$get_entry_names()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.