| is_bond | R Documentation |
A bond between two formal contexts K_1 = (G_1, M_1, I_1) and K_2 = (G_2, M_2, I_2)
is a relation R \subseteq G_1 \times M_2 such that every row of R is an intent
of K_2 and every column of R is an extent of K_1.
is_bond(fc1, fc2, relation)
fc1 |
( |
fc2 |
( |
relation |
(matrix) A binary matrix or |
TRUE if the relation is a bond, FALSE otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.