| iterative_recommender | R Documentation |
Multi-round attribute recommender: at each step computes
closure(S, reduce = TRUE) (infer + prune the rule-base), then asks
about the still-unknown attribute that appears most often in the LHS of the
active implications.
iterative_recommender(
fc,
initial = character(0),
max_rounds = 4,
interactive_mode = FALSE,
verbose = TRUE
)
fc |
A |
initial |
Character vector of attribute names known at the start. |
max_rounds |
Maximum number of question rounds. |
interactive_mode |
If |
verbose |
Print progress each round. |
Invisibly, a list with query (final Set) and
implications (the last pruned implication set).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.