| print_repo_details | R Documentation |
Prints a formatted summary of the contexts available in the FCA Repository to the console. It displays the filename, title, dimensions (objects x attributes), and description for each entry.
print_repo_details(meta)
meta |
A list of metadata objects, typically obtained via |
Prints the summary to the console. Returns NULL invisibly.
## Not run:
meta <- get_fcarepository_contexts()
print_repo_details(meta)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.