Learn R Programming

fcaR (version 1.5.0)

print_repo_details: Print Details of Repository Contexts

Description

Prints a formatted summary of the contexts available in the FCA Repository to the console. It displays the filename, title, dimensions (objects x attributes), and description for each entry.

Usage

print_repo_details(meta)

Value

Prints the summary to the console. Returns NULL invisibly.

Arguments

meta

A list of metadata objects, typically obtained via get_fcarepository_contexts.

Examples

Run this code
if (FALSE) {
meta <- get_fcarepository_contexts()
print_repo_details(meta)
}

Run the code above in your browser using DataLab