| recommendation_table | R Documentation |
Turns the named numeric vector from implications$recommend() into a
sorted data frame that is easy to read in the console or in Quarto.
recommendation_table(recoms, drop_zero = TRUE, query = NULL)
recoms |
Named numeric vector (as returned by |
drop_zero |
Logical; if |
query |
Optional character vector of attributes that were in the original
query. If set, adds a |
A data frame with columns attribute, score, and
optionally role. Rows are ordered by decreasing score, then name.
## Not run:
S <- attribute_set(fc, "Romantic", "Slow_burn")
recoms <- fc$implications$recommend(S, attribute_filter = fc$attributes)
recommendation_table(recoms)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.